#!/bin/bash
SCRIPT_PATH=$(readlink -f "$0")
SCRIPT_DIR=$(dirname "$SCRIPT_PATH")
PROPERTIES_PATH="$SCRIPT_DIR/install.properties"

load_conf()
{
  if [ -e "$PROPERTIES_PATH" ]
  then
    echo "[INFO] Lecture du fichier de configuration"
    . "$PROPERTIES_PATH"
    return 0
  else
    echo "[FAIL] Le fichier de configuration est introuvable"
    return 20
  fi
}

check_conf()
{
  EXIT_CODE=0
  
  if ! [[ "$ORANGE_ID" =~ fti/[[:alnum:]]{7} ]]
  then
    echo "[ERROR] L'identifiant orange est incorrect"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if ! [[ "$WAN_ETH" =~ eth[[:digit:]]{1,2} ]]
  then
    echo "[ERROR] L'interface WAN est incorrecte"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if ! [[ "$LAN_ETH" =~ eth[[:digit:]]{1,2} ]]
  then
    echo "[ERROR] L'interface LAN est incorrecte"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if [ "$AUTO_INSTALL" != yes -a "$AUTO_INSTALL" != no ]
  then
    echo "[ERROR] Le paramètre AUTO_INSTALL est incorrect"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  
  return $EXIT_CODE
}

do_install()
{
  if [ ! -e /sbin/dhclient3.old ]
  then
    echo "[INFO] Sauvegarde du client DHCP (/sbin/dhclient3.old)"
    mv /sbin/dhclient3 /sbin/dhclient3.old
  else
    echo "[WARN] Une sauvegarde (/sbin/dhclient3.old) du client DHCP existe deja."
  fi
  echo "[INFO] Ecriture du nouveau client DHCP"
  cp "$SCRIPT_DIR/dhclient3" /sbin/dhclient3
  chown root:root /sbin/dhclient3
  chmod 755 /sbin/dhclient3

  echo "[INFO] Inscription du hook DHCP"
  cp "$SCRIPT_DIR/rfc3442-classless-routes" /etc/dhcp3/dhclient-exit-hooks.d/
  chown root:root /etc/dhcp3/dhclient-exit-hooks.d/rfc3442-classless-routes
  chmod 755 /etc/dhcp3/dhclient-exit-hooks.d/rfc3442-classless-routes

  echo "[INFO] Installation de dibbler-client"
  export DEBIAN_FRONTEND=noninteractive
  dpkg -i "$SCRIPT_DIR/$DIBBLER_NAME"
  DEBIAN_FRONTEND=
  ORANGE_ID_HEX=$(echo -n "$ORANGE_ID" | od -tx1 | grep -oE '(\s[0-9a-f]{2})+' | sed 's/ /:/g' | sed 's/^://')
  sed "s/\(:XX\)\+/:$ORANGE_ID_HEX/g" "$SCRIPT_DIR/dibbler.client.conf-tpl.orange" > /etc/dibbler/client.conf
  chown root:root /etc/dibbler/client.conf
  chmod 755 /etc/dibbler/client.conf

  sed "s/ETH0/${WAN_ETH^^}/g" "$SCRIPT_DIR/radvd.sh" | sed "s/eth0/$WAN_ETH/g" - > /etc/dibbler/radvd.sh
  chown root:root /etc/dibbler/radvd.sh
  chmod 755 /etc/dibbler/radvd.sh

  # Installation du hooker attentif aux changements de config
  tee /config/scripts/post-config.d/dibbler-client.sh << EOF
#!/bin/bash
service dibbler-client restart
EOF
  
  chown root:root /config/scripts/post-config.d/dibbler-client.sh
  chmod 755 /config/scripts/post-config.d/dibbler-client.sh
  service dibbler-client restart

  if [ $AUTO_INSTALL == "yes" ]
  then
    touch "$AUTO_INSTALL_PATH"
    ln -s "$SCRIPT_PATH" "/config/scripts/post-config.d/orange.post-upgrade"
  fi
}

load_conf
check_conf
LOAD_EXIT_CODE=$?
if [ $LOAD_EXIT_CODE != 0 ]
then
  echo "[FAIL] Des erreurs sont présentes dans le fichier de configuration"
  exit $LOAD_EXIT_CODE
fi

if [ "$AUTO_INSTALL" == "yes" -a -e "$AUTO_INSTALL_PATH" ]
then
  echo "[INFO] $AUTO_INSTALL_PATH existe. L'installation est ignorée."
  echo "[INFO] Si vous souhaitez relancer manuellement une installation alors supprimez $AUTO_INSTALL_PATH."
  exit 0
else
  do_install
fi
