#!/bin/bash
SCRIPT_PATH=$(readlink -f "$0")
SCRIPT_DIR=$(dirname "$SCRIPT_PATH")
PROPERTIES_PATH="$SCRIPT_DIR/install.properties"

load_conf()
{
  if [ -e "$PROPERTIES_PATH" ]
  then
    echo "[INFO] Lecture du fichier de configuration"
    . "$PROPERTIES_PATH"
    return 0
  else
    echo "[FAIL] Le fichier de configuration est introuvable"
    return 20
  fi
}

check_conf()
{
  EXIT_CODE=0
  
  if ! [[ "$ORANGE_ID" =~ fti/[[:alnum:]]{7} ]]
  then
    echo "[ERROR] L'identifiant orange est incorrect"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if ! [[ "$WAN_ETH" =~ eth[[:digit:]]{1,2} ]]
  then
    echo "[ERROR] L'interface WAN est incorrecte"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if ! [[ "$LAN_ETH" =~ eth[[:digit:]]{1,2} ]]
  then
    echo "[ERROR] L'interface LAN est incorrecte"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  if [ "$AUTO_INSTALL" != yes -a "$AUTO_INSTALL" != no ]
  then
    echo "[ERROR] Le paramètre AUTO_INSTALL est incorrect"
    EXIT_CODE=`awk "BEGIN {print $EXIT_CODE+1}"`
  fi
  
  return $EXIT_CODE
}

do_uninstall()
{
  if [ -e /sbin/dhclient3.old ]
  then
    echo "[INFO] Restauration de l'ancien client DHCP"
    mv /sbin/dhclient3.old /sbin/dhclient3
  else
    echo "[WARN] La sauvegarde du client DHCP (/sbin/dhclient3.old) est introuvable! La version patchée est maintene"
  fi

  echo "[INFO] Desnscription du hook DHCP"
  rm /etc/dhcp3/dhclient-exit-hooks.d/rfc3442-classless-routes

  echo "[INFO] Desinstallation de dibbler-client"
  export DEBIAN_FRONTEND=noninteractive
  dpkg --remove dibbler-client
  DEBIAN_FRONTEND=
  rm /etc/dibbler/radvd.sh
  rm /config/scripts/post-config.d/dibbler-client.sh
  
  rm "$AUTO_INSTALL_PATH"
  rm "/config/scripts/post-config.d/orange.post-upgrade"
}

load_conf
check_conf
LOAD_EXIT_CODE=$?
if [ $LOAD_EXIT_CODE != 0 ]
then
  echo "[FAIL] Des erreurs sont présentes dans le fichier de configuration"
  exit $LOAD_EXIT_CODE
fi

do_uninstall
